@@ -17,6 +17,7 @@ const (
 	MsgID_JS_AssignToConstant
 	MsgID_JS_AssignToDefine
 	MsgID_JS_AssignToImport
+	MsgID_JS_BigInt
 	MsgID_JS_CallImportNamespace
 	MsgID_JS_ClassNameWillThrow
 	MsgID_JS_CommonJSVariableInESM
@@ -68,12 +69,14 @@ const (
 
 	// Source maps
 	MsgID_SourceMap_InvalidSourceMappings
-	MsgID_SourceMap_SectionsInSourceMap
+	MsgID_SourceMap_InvalidSourceURL
 	MsgID_SourceMap_MissingSourceMap
+	MsgID_SourceMap_SectionsInSourceMap
 	MsgID_SourceMap_UnsupportedSourceMapComment
 
 	// package.json
 	MsgID_PackageJSON_FIRST // Keep this first
+	MsgID_PackageJSON_DeadCondition
 	MsgID_PackageJSON_InvalidBrowser
 	MsgID_PackageJSON_InvalidImportsOrExports
 	MsgID_PackageJSON_InvalidSideEffects
@@ -107,6 +110,8 @@ func StringToMsgIDs(str string, logLevel LogLevel, overrides map[MsgID]LogLevel)
 		overrides[MsgID_JS_AssignToDefine] = logLevel
 	case "assign-to-import":
 		overrides[MsgID_JS_AssignToImport] = logLevel
+	case "bigint":
+		overrides[MsgID_JS_BigInt] = logLevel
 	case "call-import-namespace":
 		overrides[MsgID_JS_CallImportNamespace] = logLevel
 	case "class-name-will-throw":
@@ -203,10 +208,12 @@ func StringToMsgIDs(str string, logLevel LogLevel, overrides map[MsgID]LogLevel)
 	// Source maps
 	case "invalid-source-mappings":
 		overrides[MsgID_SourceMap_InvalidSourceMappings] = logLevel
-	case "sections-in-source-map":
-		overrides[MsgID_SourceMap_SectionsInSourceMap] = logLevel
+	case "invalid-source-url":
+		overrides[MsgID_SourceMap_InvalidSourceURL] = logLevel
 	case "missing-source-map":
 		overrides[MsgID_SourceMap_MissingSourceMap] = logLevel
+	case "sections-in-source-map":
+		overrides[MsgID_SourceMap_SectionsInSourceMap] = logLevel
 	case "unsupported-source-map-comment":
 		overrides[MsgID_SourceMap_UnsupportedSourceMapComment] = logLevel
 
@@ -239,6 +246,8 @@ func MsgIDToString(id MsgID) string {
 		return "assign-to-define"
 	case MsgID_JS_AssignToImport:
 		return "assign-to-import"
+	case MsgID_JS_BigInt:
+		return "bigint"
 	case MsgID_JS_CallImportNamespace:
 		return "call-import-namespace"
 	case MsgID_JS_ClassNameWillThrow:
@@ -335,10 +344,12 @@ func MsgIDToString(id MsgID) string {
 	// Source maps
 	case MsgID_SourceMap_InvalidSourceMappings:
 		return "invalid-source-mappings"
-	case MsgID_SourceMap_SectionsInSourceMap:
-		return "sections-in-source-map"
+	case MsgID_SourceMap_InvalidSourceURL:
+		return "invalid-source-url"
 	case MsgID_SourceMap_MissingSourceMap:
 		return "missing-source-map"
+	case MsgID_SourceMap_SectionsInSourceMap:
+		return "sections-in-source-map"
 	case MsgID_SourceMap_UnsupportedSourceMapComment:
 		return "unsupported-source-map-comment"
 
